summaryrefslogtreecommitdiff
path: root/src/cut.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-11-27 03:09:18 +0000
committerJim Meyering <jim@meyering.net>1995-11-27 03:09:18 +0000
commit7956c1508120414a4e8e1c468133b0e0214103d0 (patch)
tree2cd2b42ab8dcb0ad27efbe65c69d9b9268abdd90 /src/cut.c
parent0402200daf1f34000f50eaef97a26ea824ac3e68 (diff)
downloadcoreutils-7956c1508120414a4e8e1c468133b0e0214103d0.tar.xz
s/non-zero/nonzero/g
Diffstat (limited to 'src/cut.c')
-rw-r--r--src/cut.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/cut.c b/src/cut.c
index 89d2add95..a4ee26ac9 100644
--- a/src/cut.c
+++ b/src/cut.c
@@ -158,7 +158,7 @@ char *program_name;
static enum operating_mode operating_mode;
/* If non-zero do not output lines containing no delimeter characters.
Otherwise, all such lines are printed. This option is valid only
with field mode. */
static int suppress_non_delimited;
@@ -169,10 +169,10 @@ static int delim;
/* Nonzero if we have ever read standard input. */
static int have_read_stdin;
/* If non-zero, display usage information and exit. */
static int show_help;
/* If non-zero, print the version on standard output then exit. */
static int show_version;
static struct option const longopts[] =
@@ -321,7 +321,7 @@ print_kth (unsigned int k)
to its starting index. FIELDSTR should be composed of one or more
numbers or ranges of numbers, separated by blanks or commas.
Incomplete ranges may be given: `-m' means `1-m'; `n-' means `n'
- through end of line. Return non-zero if FIELDSTR contains at least
+ through end of line. Return nonzero if FIELDSTR contains at least
one field specification, zero otherwise. */
/* FIXME-someday: What if the user wants to cut out the 1,000,000-th field
@@ -158,7 +158,7 @@ char *program_name;
static enum operating_mode operating_mode;
-/* If non-zero do not output lines containing no delimeter characters.
+/* If nonzero do not output lines containing no delimeter characters.
Otherwise, all such lines are printed. This option is valid only
with field mode. */
@@ -169,10 +169,10 @@ static int delim;
/* Nonzero if we have ever read standard input. */
static int have_read_stdin;
-/* If non-zero, display usage information and exit. */
+/* If nonzero, display usage information and exit. */
static int show_help;
@@ -169,10 +169,10 @@ static int delim;
static int show_help;
-/* If non-zero, print the version on standard output then exit. */
+/* If nonzero, print the version on standard output then exit. */
static int show_version;
static struct option const longopts[] =